@@ -16,15 +16,15 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -51,22 +51,25 @@ from google.api import system_parameter_pb2  # type: ignore
 from google.api import usage_pb2  # type: ignore
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.servicemanagement_v1.services.service_manager import pagers
-from google.cloud.servicemanagement_v1.types import resources
-from google.cloud.servicemanagement_v1.types import servicemanager
 from google.protobuf import any_pb2  # type: ignore
 from google.protobuf import api_pb2  # type: ignore
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
 from google.protobuf import type_pb2  # type: ignore
 from google.protobuf import wrappers_pb2  # type: ignore
-from .transports.base import ServiceManagerTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import ServiceManagerGrpcAsyncIOTransport
+
+from google.cloud.servicemanagement_v1.services.service_manager import pagers
+from google.cloud.servicemanagement_v1.types import resources, servicemanager
+
 from .client import ServiceManagerClient
+from .transports.base import DEFAULT_CLIENT_INFO, ServiceManagerTransport
+from .transports.grpc_asyncio import ServiceManagerGrpcAsyncIOTransport
 
 
 class ServiceManagerAsyncClient:
-    """`Google Service Management API </service-management/overview>`__"""
+    """`Google Service Management
+    API <https://cloud.google.com/service-infrastructure/docs/overview>`__
+    """
 
     _client: ServiceManagerClient
 
@@ -242,14 +245,13 @@ class ServiceManagerAsyncClient:
         also returns all services the calling user has
         "servicemanagement.services.get" permission for.
 
-
         .. code-block:: python
 
             from google.cloud import servicemanagement_v1
 
-            def sample_list_services():
+            async def sample_list_services():
                 # Create a client
-                client = servicemanagement_v1.ServiceManagerClient()
+                client = servicemanagement_v1.ServiceManagerAsyncClient()
 
                 # Initialize request argument(s)
                 request = servicemanagement_v1.ListServicesRequest(
@@ -259,7 +261,7 @@ class ServiceManagerAsyncClient:
                 page_result = client.list_services(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -326,12 +328,20 @@ class ServiceManagerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListServicesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -349,14 +359,13 @@ class ServiceManagerAsyncClient:
         r"""Gets a managed service. Authentication is required
         unless the service is public.
 
-
         .. code-block:: python
 
             from google.cloud import servicemanagement_v1
 
-            def sample_get_service():
+            async def sample_get_service():
                 # Create a client
-                client = servicemanagement_v1.ServiceManagerClient()
+                client = servicemanagement_v1.ServiceManagerAsyncClient()
 
                 # Initialize request argument(s)
                 request = servicemanagement_v1.GetServiceRequest(
@@ -364,7 +373,7 @@ class ServiceManagerAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_service(request=request)
+                response = await client.get_service(request=request)
 
                 # Handle the response
                 print(response)
@@ -419,8 +428,21 @@ class ServiceManagerAsyncClient:
             client_info=DEFAULT_CLIENT_INFO,
         )
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("service_name", request.service_name),)
+            ),
+        )
+
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -446,14 +468,13 @@ class ServiceManagerAsyncClient:
 
         Operation<response: ManagedService>
 
-
         .. code-block:: python
 
             from google.cloud import servicemanagement_v1
 
-            def sample_create_service():
+            async def sample_create_service():
                 # Create a client
-                client = servicemanagement_v1.ServiceManagerClient()
+                client = servicemanagement_v1.ServiceManagerAsyncClient()
 
                 # Initialize request argument(s)
                 request = servicemanagement_v1.CreateServiceRequest(
@@ -464,7 +485,7 @@ class ServiceManagerAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -520,7 +541,12 @@ class ServiceManagerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -551,14 +577,13 @@ class ServiceManagerAsyncClient:
 
         Operation<response: google.protobuf.Empty>
 
-
         .. code-block:: python
 
             from google.cloud import servicemanagement_v1
 
-            def sample_delete_service():
+            async def sample_delete_service():
                 # Create a client
-                client = servicemanagement_v1.ServiceManagerClient()
+                client = servicemanagement_v1.ServiceManagerAsyncClient()
 
                 # Initialize request argument(s)
                 request = servicemanagement_v1.DeleteServiceRequest(
@@ -570,7 +595,7 @@ class ServiceManagerAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -581,8 +606,9 @@ class ServiceManagerAsyncClient:
                 method.
             service_name (:class:`str`):
                 Required. The name of the service. See the
-                `overview </service-management/overview>`__ for naming
-                requirements. For example: ``example.googleapis.com``.
+                `overview <https://cloud.google.com/service-infrastructure/docs/overview>`__
+                for naming requirements. For example:
+                ``example.googleapis.com``.
 
                 This corresponds to the ``service_name`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -637,8 +663,21 @@ class ServiceManagerAsyncClient:
             client_info=DEFAULT_CLIENT_INFO,
         )
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("service_name", request.service_name),)
+            ),
+        )
+
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -668,14 +707,13 @@ class ServiceManagerAsyncClient:
 
         Operation<response: UndeleteServiceResponse>
 
-
         .. code-block:: python
 
             from google.cloud import servicemanagement_v1
 
-            def sample_undelete_service():
+            async def sample_undelete_service():
                 # Create a client
-                client = servicemanagement_v1.ServiceManagerClient()
+                client = servicemanagement_v1.ServiceManagerAsyncClient()
 
                 # Initialize request argument(s)
                 request = servicemanagement_v1.UndeleteServiceRequest(
@@ -687,7 +725,7 @@ class ServiceManagerAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -698,8 +736,9 @@ class ServiceManagerAsyncClient:
                 method.
             service_name (:class:`str`):
                 Required. The name of the service. See the
-                `overview </service-management/overview>`__ for naming
-                requirements. For example: ``example.googleapis.com``.
+                `overview <https://cloud.google.com/service-infrastructure/docs/overview>`__
+                for naming requirements. For example:
+                ``example.googleapis.com``.
 
                 This corresponds to the ``service_name`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -744,8 +783,21 @@ class ServiceManagerAsyncClient:
             client_info=DEFAULT_CLIENT_INFO,
         )
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("service_name", request.service_name),)
+            ),
+        )
+
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -770,14 +822,13 @@ class ServiceManagerAsyncClient:
         r"""Lists the history of the service configuration for a
         managed service, from the newest to the oldest.
 
-
         .. code-block:: python
 
             from google.cloud import servicemanagement_v1
 
-            def sample_list_service_configs():
+            async def sample_list_service_configs():
                 # Create a client
-                client = servicemanagement_v1.ServiceManagerClient()
+                client = servicemanagement_v1.ServiceManagerAsyncClient()
 
                 # Initialize request argument(s)
                 request = servicemanagement_v1.ListServiceConfigsRequest(
@@ -788,7 +839,7 @@ class ServiceManagerAsyncClient:
                 page_result = client.list_service_configs(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -797,8 +848,9 @@ class ServiceManagerAsyncClient:
                 ListServiceConfigs method.
             service_name (:class:`str`):
                 Required. The name of the service. See the
-                `overview </service-management/overview>`__ for naming
-                requirements. For example: ``example.googleapis.com``.
+                `overview <https://cloud.google.com/service-infrastructure/docs/overview>`__
+                for naming requirements. For example:
+                ``example.googleapis.com``.
 
                 This corresponds to the ``service_name`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -843,13 +895,29 @@ class ServiceManagerAsyncClient:
             client_info=DEFAULT_CLIENT_INFO,
         )
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("service_name", request.service_name),)
+            ),
+        )
+
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListServiceConfigsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -869,14 +937,13 @@ class ServiceManagerAsyncClient:
         r"""Gets a service configuration (version) for a managed
         service.
 
-
         .. code-block:: python
 
             from google.cloud import servicemanagement_v1
 
-            def sample_get_service_config():
+            async def sample_get_service_config():
                 # Create a client
-                client = servicemanagement_v1.ServiceManagerClient()
+                client = servicemanagement_v1.ServiceManagerAsyncClient()
 
                 # Initialize request argument(s)
                 request = servicemanagement_v1.GetServiceConfigRequest(
@@ -885,7 +952,7 @@ class ServiceManagerAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_service_config(request=request)
+                response = await client.get_service_config(request=request)
 
                 # Handle the response
                 print(response)
@@ -896,8 +963,9 @@ class ServiceManagerAsyncClient:
                 method.
             service_name (:class:`str`):
                 Required. The name of the service. See the
-                `overview </service-management/overview>`__ for naming
-                requirements. For example: ``example.googleapis.com``.
+                `overview <https://cloud.google.com/service-infrastructure/docs/overview>`__
+                for naming requirements. For example:
+                ``example.googleapis.com``.
 
                 This corresponds to the ``service_name`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -977,8 +1045,24 @@ class ServiceManagerAsyncClient:
             client_info=DEFAULT_CLIENT_INFO,
         )
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("service_name", request.service_name),
+                    ("config_id", request.config_id),
+                )
+            ),
+        )
+
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1003,14 +1087,13 @@ class ServiceManagerAsyncClient:
         referenced by existing rollouts are kept for each service. The
         rest will be deleted eventually.
 
-
         .. code-block:: python
 
             from google.cloud import servicemanagement_v1
 
-            def sample_create_service_config():
+            async def sample_create_service_config():
                 # Create a client
-                client = servicemanagement_v1.ServiceManagerClient()
+                client = servicemanagement_v1.ServiceManagerAsyncClient()
 
                 # Initialize request argument(s)
                 request = servicemanagement_v1.CreateServiceConfigRequest(
@@ -1018,7 +1101,7 @@ class ServiceManagerAsyncClient:
                 )
 
                 # Make the request
-                response = client.create_service_config(request=request)
+                response = await client.create_service_config(request=request)
 
                 # Handle the response
                 print(response)
@@ -1029,8 +1112,9 @@ class ServiceManagerAsyncClient:
                 CreateServiceConfig method.
             service_name (:class:`str`):
                 Required. The name of the service. See the
-                `overview </service-management/overview>`__ for naming
-                requirements. For example: ``example.googleapis.com``.
+                `overview <https://cloud.google.com/service-infrastructure/docs/overview>`__
+                for naming requirements. For example:
+                ``example.googleapis.com``.
 
                 This corresponds to the ``service_name`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1098,8 +1182,21 @@ class ServiceManagerAsyncClient:
             client_info=DEFAULT_CLIENT_INFO,
         )
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("service_name", request.service_name),)
+            ),
+        )
+
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1129,14 +1226,13 @@ class ServiceManagerAsyncClient:
 
         Operation<response: SubmitConfigSourceResponse>
 
-
         .. code-block:: python
 
             from google.cloud import servicemanagement_v1
 
-            def sample_submit_config_source():
+            async def sample_submit_config_source():
                 # Create a client
-                client = servicemanagement_v1.ServiceManagerClient()
+                client = servicemanagement_v1.ServiceManagerAsyncClient()
 
                 # Initialize request argument(s)
                 request = servicemanagement_v1.SubmitConfigSourceRequest(
@@ -1148,7 +1244,7 @@ class ServiceManagerAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1159,8 +1255,9 @@ class ServiceManagerAsyncClient:
                 SubmitConfigSource method.
             service_name (:class:`str`):
                 Required. The name of the service. See the
-                `overview </service-management/overview>`__ for naming
-                requirements. For example: ``example.googleapis.com``.
+                `overview <https://cloud.google.com/service-infrastructure/docs/overview>`__
+                for naming requirements. For example:
+                ``example.googleapis.com``.
 
                 This corresponds to the ``service_name`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1225,8 +1322,21 @@ class ServiceManagerAsyncClient:
             client_info=DEFAULT_CLIENT_INFO,
         )
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("service_name", request.service_name),)
+            ),
+        )
+
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1253,14 +1363,13 @@ class ServiceManagerAsyncClient:
         rollouts for a managed service, from the newest to the
         oldest.
 
-
         .. code-block:: python
 
             from google.cloud import servicemanagement_v1
 
-            def sample_list_service_rollouts():
+            async def sample_list_service_rollouts():
                 # Create a client
-                client = servicemanagement_v1.ServiceManagerClient()
+                client = servicemanagement_v1.ServiceManagerAsyncClient()
 
                 # Initialize request argument(s)
                 request = servicemanagement_v1.ListServiceRolloutsRequest(
@@ -1272,7 +1381,7 @@ class ServiceManagerAsyncClient:
                 page_result = client.list_service_rollouts(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -1281,8 +1390,9 @@ class ServiceManagerAsyncClient:
                 'ListServiceRollouts'
             service_name (:class:`str`):
                 Required. The name of the service. See the
-                `overview </service-management/overview>`__ for naming
-                requirements. For example: ``example.googleapis.com``.
+                `overview <https://cloud.google.com/service-infrastructure/docs/overview>`__
+                for naming requirements. For example:
+                ``example.googleapis.com``.
 
                 This corresponds to the ``service_name`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1290,11 +1400,11 @@ class ServiceManagerAsyncClient:
             filter (:class:`str`):
                 Required. Use ``filter`` to return subset of rollouts.
                 The following filters are supported: -- To limit the
-                results to only those in
-                `status <google.api.servicemanagement.v1.RolloutStatus>`__
+                results to only those in status
+                (google.api.servicemanagement.v1.RolloutStatus)
                 'SUCCESS', use filter='status=SUCCESS' -- To limit the
-                results to those in
-                `status <google.api.servicemanagement.v1.RolloutStatus>`__
+                results to those in status
+                (google.api.servicemanagement.v1.RolloutStatus)
                 'CANCELLED' or 'FAILED', use filter='status=CANCELLED OR
                 status=FAILED'
 
@@ -1343,13 +1453,29 @@ class ServiceManagerAsyncClient:
             client_info=DEFAULT_CLIENT_INFO,
         )
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("service_name", request.service_name),)
+            ),
+        )
+
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListServiceRolloutsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1368,14 +1494,13 @@ class ServiceManagerAsyncClient:
         r"""Gets a service configuration
         [rollout][google.api.servicemanagement.v1.Rollout].
 
-
         .. code-block:: python
 
             from google.cloud import servicemanagement_v1
 
-            def sample_get_service_rollout():
+            async def sample_get_service_rollout():
                 # Create a client
-                client = servicemanagement_v1.ServiceManagerClient()
+                client = servicemanagement_v1.ServiceManagerAsyncClient()
 
                 # Initialize request argument(s)
                 request = servicemanagement_v1.GetServiceRolloutRequest(
@@ -1384,7 +1509,7 @@ class ServiceManagerAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_service_rollout(request=request)
+                response = await client.get_service_rollout(request=request)
 
                 # Handle the response
                 print(response)
@@ -1395,8 +1520,9 @@ class ServiceManagerAsyncClient:
                 GetServiceRollout method.
             service_name (:class:`str`):
                 Required. The name of the service. See the
-                `overview </service-management/overview>`__ for naming
-                requirements. For example: ``example.googleapis.com``.
+                `overview <https://cloud.google.com/service-infrastructure/docs/overview>`__
+                for naming requirements. For example:
+                ``example.googleapis.com``.
 
                 This corresponds to the ``service_name`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1451,8 +1577,24 @@ class ServiceManagerAsyncClient:
             client_info=DEFAULT_CLIENT_INFO,
         )
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (
+                    ("service_name", request.service_name),
+                    ("rollout_id", request.rollout_id),
+                )
+            ),
+        )
+
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1485,14 +1627,13 @@ class ServiceManagerAsyncClient:
 
         Operation<response: Rollout>
 
-
         .. code-block:: python
 
             from google.cloud import servicemanagement_v1
 
-            def sample_create_service_rollout():
+            async def sample_create_service_rollout():
                 # Create a client
-                client = servicemanagement_v1.ServiceManagerClient()
+                client = servicemanagement_v1.ServiceManagerAsyncClient()
 
                 # Initialize request argument(s)
                 request = servicemanagement_v1.CreateServiceRolloutRequest(
@@ -1504,7 +1645,7 @@ class ServiceManagerAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1515,8 +1656,9 @@ class ServiceManagerAsyncClient:
                 'CreateServiceRollout'
             service_name (:class:`str`):
                 Required. The name of the service. See the
-                `overview </service-management/overview>`__ for naming
-                requirements. For example: ``example.googleapis.com``.
+                `overview <https://cloud.google.com/service-infrastructure/docs/overview>`__
+                for naming requirements. For example:
+                ``example.googleapis.com``.
 
                 This corresponds to the ``service_name`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1571,8 +1713,21 @@ class ServiceManagerAsyncClient:
             client_info=DEFAULT_CLIENT_INFO,
         )
 
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata(
+                (("service_name", request.service_name),)
+            ),
+        )
+
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1608,21 +1763,20 @@ class ServiceManagerAsyncClient:
         method will compare GenerateConfigReportRequest.new_value with
         the last pushed service configuration.
 
-
         .. code-block:: python
 
             from google.cloud import servicemanagement_v1
 
-            def sample_generate_config_report():
+            async def sample_generate_config_report():
                 # Create a client
-                client = servicemanagement_v1.ServiceManagerClient()
+                client = servicemanagement_v1.ServiceManagerAsyncClient()
 
                 # Initialize request argument(s)
                 request = servicemanagement_v1.GenerateConfigReportRequest(
                 )
 
                 # Make the request
-                response = client.generate_config_report(request=request)
+                response = await client.generate_config_report(request=request)
 
                 # Handle the response
                 print(response)
@@ -1693,7 +1847,12 @@ class ServiceManagerAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
